@@ -11,11 +11,7 @@ from trinsicokapi.proto.okapi.security.v1 import (
 
 from trinsic.proto.sdk.options.v1 import ServiceOptions
 from trinsic.proto.services.account.v1 import *
-from trinsic.proto.services.account.v1 import (
-    LoginConfirmRequest,
-    LoginRequest,
-    LoginResponse,
-)
+from trinsic.security_providers import ITokenProvider
 from trinsic.service_base import ServiceBase
 
 
@@ -25,26 +21,27 @@ class AccountService(ServiceBase):
     def __init__(
         self,
         server_config: ServiceOptions = None,
+        token_provider: ITokenProvider = None,
     ):
         """
         Initialize a connection to the server.
         Args:
             server_config: The URL of the server, or a channel which encapsulates the connection already.
         """
-        super().__init__(server_config)
-        self.client: AccountStub = self.stub_with_metadata(AccountStub)
+        super().__init__(server_config, token_provider)
+        self.client = AccountStub(super().channel)
 
     async def sign_in(self, *, request: SignInRequest = None) -> str:
         """
         Deprecated - use `AccountService.login` and `AccountService.login_confirm` instead
         """
         request = request or SignInRequest()
-        request.ecosystem_id = (
-            request.ecosystem_id or self.service_options.default_ecosystem
+        request.ecosystem_id = request.ecosystem_id or "default"
+        response = await self.client.sign_in(
+            sign_in_request=request, metadata=self.build_metadata()
         )
-        response = await self.client.sign_in(sign_in_request=request)
         auth_token = base64.urlsafe_b64encode(bytes(response.profile)).decode("utf-8")
-        self.service_options.auth_token = auth_token
+        self.token_provider.save(auth_token)
         return auth_token
 
     @staticmethod
@@ -105,10 +102,12 @@ class AccountService(ServiceBase):
             LoginResponse with challenge
         """
         request = request or LoginRequest()
-        request.ecosystem_id = (
-            request.ecosystem_id or self.service_options.default_ecosystem
-        )
-        return await self.client.login(request)
+        response = await self.client.login(request, metadata=self.build_metadata())
+        if response.profile:
+            self.token_provider.save(
+                base64.urlsafe_b64encode(bytes(response.profile)).decode("utf8")
+            )
+        return response
 
     async def login_confirm(self, *, challenge: bytes, auth_code: str) -> str:
         """
@@ -128,26 +127,33 @@ class AccountService(ServiceBase):
         request = LoginConfirmRequest(
             challenge=challenge, confirmation_code_hashed=code_hash
         )
-        response = await self.client.login_confirm(request)
+        response = await self.client.login_confirm(
+            request, metadata=self.build_metadata()
+        )
 
         auth_token = base64.urlsafe_b64encode(bytes(response.profile)).decode("utf-8")
 
         if response.profile.protection.enabled:
             auth_token = self.unprotect(profile=auth_token, security_code=auth_code)
 
-        self.service_options.auth_token = auth_token
+        self.token_provider.save(auth_token)
         return auth_token
 
-    async def login_anonymous(self) -> string:
+    async def login_anonymous(self, *, ecosystem_id: string = None) -> string:
         """
-        Create an anonymous account in the current ecosystem
+        Create an anonymous account in the given ecosystem
+        Args:
+            ecosystem_id: ID of ecosystem to sign into; defaults to "default" if unspecified
         Returns:
             Authentication token for newly-created account
         """
-        response = await self.login(request=LoginRequest())
+
+        ecosystem_id = ecosystem_id or "default"
+
+        response = await self.login(request=LoginRequest(ecosystem_id=ecosystem_id))
         auth_token = base64.urlsafe_b64encode(bytes(response.profile)).decode("utf-8")
 
-        self.service_options.auth_token = auth_token
+        self.token_provider.save(auth_token)
 
         return auth_token
 
@@ -157,17 +163,40 @@ class AccountService(ServiceBase):
         Returns:
             The `InfoResponse`
         """
-        return await self.client.info(account_info_request=AccountInfoRequest())
+        return await self.info()
+
+    # BEGIN Code generated by protoc-gen-trinsic. DO NOT EDIT.
+    # target: /home/runner/work/sdk/sdk/python/trinsic/account_service.py
+
+    async def info(self) -> AccountInfoResponse:
+        """Get account information"""
+        request = AccountInfoRequest()
+        return await self.client.info(request, metadata=self.build_metadata(request))
 
     async def list_devices(self, *, request: ListDevicesRequest) -> ListDevicesResponse:
-        return await self.client.list_devices(list_devices_request=request)
+        """List all connected devices"""
+
+        return await self.client.list_devices(
+            request, metadata=self.build_metadata(request)
+        )
 
     async def revoke_device(
         self, *, request: RevokeDeviceRequest
     ) -> RevokeDeviceResponse:
-        return await self.client.revoke_device(revoke_device_request=request)
+        """Revoke device access to the account's cloud wallet"""
+
+        return await self.client.revoke_device(
+            request, metadata=self.build_metadata(request)
+        )
 
     async def authorize_webhook(
         self, *, request: AuthorizeWebhookRequest
     ) -> AuthorizeWebhookResponse:
-        return await self.client.authorize_webhook(authorize_webhook_request=request)
+        """Authorize Ecosystem to receive webhook events"""
+
+        return await self.client.authorize_webhook(
+            request, metadata=self.build_metadata(request)
+        )
+
+
+# END Code generated by protoc-gen-trinsic. DO NOT EDIT.
